@@ -7,6 +7,7 @@
 
 #include <errno.h>
 #include <getopt.h>
+#include <unistd.h>
 
 #define HASH_CHECK_MODE_SET \
 {\
@@ -288,14 +289,18 @@ void analyze_argument(const int argc, char **argv, OPArg *oparg)
 	}
 
 	{
+		long psize = sysconf(_SC_PAGESIZE);
 		int size = oparg->buffer_size;
 		VList *b_size_list = NULL;
 
 		for(;;)
 		{
-			int *i = malloc(sizeof(int));
-			*i = size;
-			b_size_list = append_list(b_size_list, i);
+			if((size % psize) == 0)
+			{
+				int *i = malloc(sizeof(int));
+				*i = size;
+				b_size_list = append_list(b_size_list, i);
+			}
 
 			if(size <= 524288)
 			{
