@@ -4,6 +4,7 @@
 #include "struct_CPDD.h"
 
 #include <stdio.h>
+#include <string.h>
 
 #include <errno.h>
 
@@ -14,7 +15,11 @@ static inline void print_error(const char *func, const char *file, const int lin
 static inline void print_error(const char *func, const char *file, const int line, CPDD *cpdd)
 {
 	printf("%s : %d行\n", file, line);
-	perror(func);
+	if(strcmp(func, "NODATA") != 0)
+	{
+		perror(func);
+	}
+
 	cpdd->total_error++;
 }
 
