@@ -1,5 +1,5 @@
-#ifndef INCLUDED_STRUCT_SOURCEDATA_H
-#define INCLUDED_STRUCT_SOURCEDATA_H
+#ifndef STRUCT_SOURCE_DATA_H
+#define STRUCT_SOURCE_DATA_H
 
 #include "struct_CPDD.h"
 #include "struct_VList.h"
